==> illuminat-1.1.4.tar.gz: illuminat-1.1.4/setup.py <==
from setuptools import setup, find_packages
import codecs
import os


VERSION = '1.1.4'
DESCRIPTION = 'Illuminat: Revolutionizing Education through Personalization'

# Setting up
setup(
    name="illuminat",
    version=VERSION,
    author="Amey Aggarwal",
    author_email="ameyaggarwal.sms@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    package_data={'illuminat': ['main.kv', 'icystrisall-3340d35fc565.json']},
    install_requires=[
        'adal==1.2.7',
        'aiohttp==3.9.3',
        'aiosignal==1.3.1',
        'altgraph==0.17.4',
        'annotated-types==0.6.0',
        'anyio==4.2.0',
        'appdirs==1.4.4',
        'asyncgui==0.6.1',
        'asyncio==3.4.3',
        'asynckivy==0.6.2',
        'attrs==23.2.0',
        'audioread==3.0.1',
        'auto-py-to-exe==2.43.3',
        'azure-ai-textanalytics==5.3.0',
        'azure-ai-translation-text==1.0.0b1',
        'azure-applicationinsights==0.1.1',
        'azure-batch==4.1.3',
        'azure-cognitiveservices-language-luis==0.7.0',
        'azure-cognitiveservices-language-spellcheck==2.0.0',
        'azure-cognitiveservices-language-textanalytics==0.2.1',
        'azure-cognitiveservices-speech==1.36.0',
        'azure-common==1.1.28',
        'azure-core==1.30.1',
        'azure-cosmosdb-nspkg==2.0.2',
        'azure-cosmosdb-table==1.0.6',
        'azure-datalake-store==0.0.53',
        'azure-eventgrid==1.3.0',
        'azure-graphrbac==0.40.0',
        'azure-identity==1.15.0',
        'azure-keyvault==1.1.0',
        'azure-loganalytics==0.1.1',
        'azure-mgmt==4.0.0',
        'azure-mgmt-advisor==1.0.1',
        'azure-mgmt-applicationinsights==0.1.1',
        'azure-mgmt-authorization==0.50.0',
        'azure-mgmt-batch==5.0.1',
        'azure-mgmt-batchai==2.0.0',
        'azure-mgmt-billing==0.2.0',
        'azure-mgmt-cdn==3.1.0',
        'azure-mgmt-cognitiveservices==3.0.0',
        'azure-mgmt-commerce==1.0.1',
        'azure-mgmt-compute==4.6.2',
        'azure-mgmt-consumption==2.0.0',
        'azure-mgmt-containerinstance==1.5.0',
        'azure-mgmt-containerregistry==2.8.0',
        'azure-mgmt-containerservice==4.4.0',
        'azure-mgmt-core==1.4.0',
        'azure-mgmt-cosmosdb==0.4.1',
        'azure-mgmt-datafactory==0.6.0',
        'azure-mgmt-datalake-analytics==0.6.0',
        'azure-mgmt-datalake-nspkg==3.0.1',
        'azure-mgmt-datalake-store==0.5.0',
        'azure-mgmt-datamigration==1.0.0',
        'azure-mgmt-devspaces==0.1.0',
        'azure-mgmt-devtestlabs==2.2.0',
        'azure-mgmt-dns==2.1.0',
        'azure-mgmt-eventgrid==1.0.0',
        'azure-mgmt-eventhub==2.6.0',
        'azure-mgmt-hanaonazure==0.1.1',
        'azure-mgmt-iotcentral==0.1.0',
        'azure-mgmt-iothub==0.5.0',
        'azure-mgmt-iothubprovisioningservices==0.2.0',
        'azure-mgmt-keyvault==1.1.0',
        'azure-mgmt-loganalytics==0.2.0',
        'azure-mgmt-logic==3.0.0',
        'azure-mgmt-machinelearningcompute==0.4.1',
        'azure-mgmt-managementgroups==0.1.0',
        'azure-mgmt-managementpartner==0.1.1',
        'azure-mgmt-maps==0.1.0',
        'azure-mgmt-marketplaceordering==0.1.0',
        'azure-mgmt-media==1.0.1',
        'azure-mgmt-monitor==0.5.2',
        'azure-mgmt-msi==0.2.0',
        'azure-mgmt-network==2.7.0',
        'azure-mgmt-notificationhubs==2.1.0',
        'azure-mgmt-nspkg==3.0.2',
        'azure-mgmt-policyinsights==0.1.0',
        'azure-mgmt-powerbiembedded==2.0.0',
        'azure-mgmt-rdbms==1.9.0',
        'azure-mgmt-recoveryservices==0.3.0',
        'azure-mgmt-recoveryservicesbackup==0.3.0',
        'azure-mgmt-redis==5.0.0',
        'azure-mgmt-relay==0.1.0',
        'azure-mgmt-reservations==0.2.1',
        'azure-mgmt-resource==2.2.0',
        'azure-mgmt-scheduler==2.0.0',
        'azure-mgmt-search==2.1.0',
        'azure-mgmt-servicebus==0.5.3',
        'azure-mgmt-servicefabric==0.2.0',
        'azure-mgmt-signalr==0.1.1',
        'azure-mgmt-sql==0.9.1',
        'azure-mgmt-storage==2.0.0',
        'azure-mgmt-subscription==0.2.0',
        'azure-mgmt-trafficmanager==0.50.0',
        'azure-mgmt-web==0.35.0',
        'azure-nspkg==3.0.2',
        'azure-servicebus==0.21.1',
        'azure-servicefabric==6.3.0.0',
        'azure-servicemanagement-legacy==0.20.7',
        'azure-storage-blob==1.5.0',
        'azure-storage-common==1.4.2',
        'azure-storage-file==1.4.0',
        'azure-storage-queue==1.4.0',
        'backports.tarfile==1.0.0',
        'blinker==1.7.0',
        'bottle==0.12.25',
        'bottle-websocket==0.2.9',
        'build==1.0.3',
        'buildozer==1.5.0',
        'CacheControl==0.13.1',
        'cachetools==5.3.2',
        'certifi==2024.2.2',
        'cffi==1.16.0',
        'chardet==3.0.4',
        'charset-normalizer==3.3.2',
        'click==8.1.7',
        'colorama==0.4.6',
        'cryptography==41.0.7',
        'Cython==0.29.19',
        'decorator==4.4.2',
        'distlib==0.3.8',
        'distro==1.9.0',
        'docutils==0.20.1',
        'Eel==0.16.0',
        'et-xmlfile==1.1.0',
        'ffpyplayer==4.5.1',
        'filelock==3.13.1',
        'firebase-admin==6.4.0',
        'Flask==3.0.2',
        'frozenlist==1.4.1',
        'fsspec==2024.3.1',
        'future==1.0.0',
        'gevent==24.2.1',
        'gevent-websocket==0.10.1',
        'google-api-core==2.15.0',
        'google-api-python-client==2.113.0',
        'google-auth==2.29.0',
        'google-auth-httplib2==0.2.0',
        'google-cloud-core==2.4.1',
        'google-cloud-firestore==2.14.0',
        'google-cloud-storage==2.14.0',
        'google-crc32c==1.5.0',
        'google-resumable-media==2.7.0',
        'googleapis-common-protos==1.62.0',
        'greenlet==3.0.3',
        'grpcio==1.60.0',
        'grpcio-status==1.60.0',
        'gTTS==2.5.1',
        'h11==0.14.0',
        'h2==3.2.0',
        'hpack==3.0.0',
        'hstspreload==2024.2.1',
        'httpcore==1.0.4',
        'httplib2==0.22.0',
        'httpx==0.27.0',
        'huggingface-hub==0.22.2',
        'hyperframe==5.2.0',
        'idna==3.6',
        'imageio==2.33.1',
        'imageio-ffmpeg==0.4.9',
        'importlib_metadata==7.1.0',
        'isodate==0.6.1',
        'itsdangerous==2.1.2',
        'jaraco.classes==3.4.0',
        'jaraco.context==5.3.0',
        'jaraco.functools==4.0.0',
        'Jinja2==3.1.3',
        'joblib==1.3.2',
        'keyring==25.1.0',
        'kivy',
        'kivy-deps.angle==0.4.0',
        'kivy-deps.glew==0.3.1',
        'kivy-deps.sdl2==0.7.0',
        'Kivy-Garden==0.1.5',
        'kivymd==1.2.0',
        'lazy_loader==0.3',
        'libretranslatepy==2.1.1',
        'librosa==0.10.1',
        'llvmlite==0.42.0',
        'lxml==5.1.0',
        'markdown-it-py==3.0.0',
        'MarkupSafe==2.1.5',
        'materialyoucolor==2.0.7',
        'mdurl==0.1.2',
        'more-itertools==10.2.0',
        'moviepy==1.0.3',
        'mpmath==1.3.0',
        'msal==1.28.0',
        'msal-extensions==1.1.0',
        'msgpack==1.0.7',
        'msrest==0.7.1',
        'msrestazure==0.6.4',
        'mtranslate==1.8',
        'multidict==6.0.5',
        'networkx==3.2.1',
        'nh3==0.2.17',
        'numba==0.59.0',
        'numpy==1.26.3',
        'oauthlib==3.2.2',
        'openai==0.6.0',
        'openpyxl==3.1.2',
        'packaging==23.2',
        'pandas==2.2.1',
        'pandas-stubs==2.2.1.240316',
        'pefile==2023.2.7',
        'pexpect==4.9.0',
        'pillow==10.3.0',
        'pip-tools==7.4.0',
        'pkginfo==1.10.0',
        'platformdirs==4.2.0',
        'pooch==1.8.1',
        'portalocker==2.8.2',
        'proglog==0.1.10',
        'proto-plus==1.23.0',
        'protobuf==4.25.2',
        'ptyprocess==0.7.0',
        'pyasn1==0.5.1',
        'pyasn1-modules==0.3.0',
        'pycparser==2.21',
        'pydantic==2.6.4',
        'pydantic_core==2.16.3',
        'pydub==0.25.1',
        'Pygments==2.17.2',
        'pyinstaller==6.5.0',
        'pyinstaller-hooks-contrib==2024.3',
        'PyJWT==2.8.0',
        'pyparsing==3.1.1',
        'pypiwin32==223',
        'pyproject_hooks==1.0.0',
        'python-dateutil==2.9.0.post0',
        'pytz==2024.1',
        'pywin32==306',
        'pywin32-ctypes==0.2.2',
        'PyYAML==6.0.1',
        'readme_renderer==43.0',
        'regex==2023.12.25',
        'requests==2.31.0',
        'requests-oauthlib==2.0.0',
        'requests-toolbelt==1.0.0',
        'rfc3986==1.5.0',
        'rich==13.7.1',
        'rsa==4.9',
        'safetensors==0.4.2',
        'scikit-learn==1.4.1.post1',
        'scipy==1.12.0',
        'sh==2.0.6',
        'six==1.16.0',
        'sniffio==1.3.0',
        'soundfile==0.12.1',
        'soxr==0.3.7',
        'supyr-struct==1.5.4',
        'sympy==1.12',
        'threadpoolctl==3.3.0',
        'tokenizers==0.15.2',
        'toml==0.10.2',
        'torchaudio==2.2.2',
        'torchvision==0.17.2',
        'tqdm==4.66.1',
        'transformers==4.39.2',
        'translate==3.6.1',
        'twine==5.0.0',
        'types-pytz==2024.1.0.20240203',
        'typing_extensions==4.9.0',
        'tzdata==2024.1',
        'uritemplate==4.1.1',
        'urllib3==2.2.1',
        'uuid==1.30',
        'virtualenv==20.25.1',
        'watch==0.2.7',
        'Werkzeug==3.0.1',
        'whichcraft==0.6.1',
        'yarl==1.9.4',
        'zipp==3.18.1',
        'zope.event==5.0',
        'zope.interface==6.2'
    ],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)

==> illuminat-1.1.5.tar.gz: illuminat-1.1.5/setup.py <==
from setuptools import setup, find_packages
import codecs
import os


VERSION = '1.1.5'
DESCRIPTION = 'Illuminat: Revolutionizing Education through Personalization'

# Setting up
setup(
    name="illuminat",
    version=VERSION,
    author="Amey Aggarwal",
    author_email="<ameyaggarwal.sms@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    package_data={'illuminat': ['icystrisall-3340d35fc565.json']},
    install_requires=[
        'adal==1.2.7',
        'aiohttp==3.9.3',
        'aiosignal==1.3.1',
        'altgraph==0.17.4',
        'annotated-types==0.6.0',
        'anyio==4.2.0',
        'appdirs==1.4.4',
        'asyncgui==0.6.1',
        'asyncio==3.4.3',
        'asynckivy==0.6.2',
        'attrs==23.2.0',
        'audioread==3.0.1',
        'auto-py-to-exe==2.43.3',
        'azure-ai-textanalytics==5.3.0',
        'azure-ai-translation-text==1.0.0b1',
        'azure-applicationinsights==0.1.1',
        'azure-batch==4.1.3',
        'azure-cognitiveservices-language-luis==0.7.0',
        'azure-cognitiveservices-language-spellcheck==2.0.0',
        'azure-cognitiveservices-language-textanalytics==0.2.1',
        'azure-cognitiveservices-speech==1.36.0',
        'azure-common==1.1.28',
        'azure-core==1.30.1',
        'azure-cosmosdb-nspkg==2.0.2',
        'azure-cosmosdb-table==1.0.6',
        'azure-datalake-store==0.0.53',
        'azure-eventgrid==1.3.0',
        'azure-graphrbac==0.40.0',
        'azure-identity==1.15.0',
        'azure-keyvault==1.1.0',
        'azure-loganalytics==0.1.1',
        'azure-mgmt==4.0.0',
        'azure-mgmt-advisor==1.0.1',
        'azure-mgmt-applicationinsights==0.1.1',
        'azure-mgmt-authorization==0.50.0',
        'azure-mgmt-batch==5.0.1',
        'azure-mgmt-batchai==2.0.0',
        'azure-mgmt-billing==0.2.0',
        'azure-mgmt-cdn==3.1.0',
        'azure-mgmt-cognitiveservices==3.0.0',
        'azure-mgmt-commerce==1.0.1',
        'azure-mgmt-compute==4.6.2',
        'azure-mgmt-consumption==2.0.0',
        'azure-mgmt-containerinstance==1.5.0',
        'azure-mgmt-containerregistry==2.8.0',
        'azure-mgmt-containerservice==4.4.0',
        'azure-mgmt-core==1.4.0',
        'azure-mgmt-cosmosdb==0.4.1',
        'azure-mgmt-datafactory==0.6.0',
        'azure-mgmt-datalake-analytics==0.6.0',
        'azure-mgmt-datalake-nspkg==3.0.1',
        'azure-mgmt-datalake-store==0.5.0',
        'azure-mgmt-datamigration==1.0.0',
        'azure-mgmt-devspaces==0.1.0',
        'azure-mgmt-devtestlabs==2.2.0',
        'azure-mgmt-dns==2.1.0',
        'azure-mgmt-eventgrid==1.0.0',
        'azure-mgmt-eventhub==2.6.0',
        'azure-mgmt-hanaonazure==0.1.1',
        'azure-mgmt-iotcentral==0.1.0',
        'azure-mgmt-iothub==0.5.0',
        'azure-mgmt-iothubprovisioningservices==0.2.0',
        'azure-mgmt-keyvault==1.1.0',
        'azure-mgmt-loganalytics==0.2.0',
        'azure-mgmt-logic==3.0.0',
        'azure-mgmt-machinelearningcompute==0.4.1',
        'azure-mgmt-managementgroups==0.1.0',
        'azure-mgmt-managementpartner==0.1.1',
        'azure-mgmt-maps==0.1.0',
        'azure-mgmt-marketplaceordering==0.1.0',
        'azure-mgmt-media==1.0.1',
        'azure-mgmt-monitor==0.5.2',
        'azure-mgmt-msi==0.2.0',
        'azure-mgmt-network==2.7.0',
        'azure-mgmt-notificationhubs==2.1.0',
        'azure-mgmt-nspkg==3.0.2',
        'azure-mgmt-policyinsights==0.1.0',
        'azure-mgmt-powerbiembedded==2.0.0',
        'azure-mgmt-rdbms==1.9.0',
        'azure-mgmt-recoveryservices==0.3.0',
        'azure-mgmt-recoveryservicesbackup==0.3.0',
        'azure-mgmt-redis==5.0.0',
        'azure-mgmt-relay==0.1.0',
        'azure-mgmt-reservations==0.2.1',
        'azure-mgmt-resource==2.2.0',
        'azure-mgmt-scheduler==2.0.0',
        'azure-mgmt-search==2.1.0',
        'azure-mgmt-servicebus==0.5.3',
        'azure-mgmt-servicefabric==0.2.0',
        'azure-mgmt-signalr==0.1.1',
        'azure-mgmt-sql==0.9.1',
        'azure-mgmt-storage==2.0.0',
        'azure-mgmt-subscription==0.2.0',
        'azure-mgmt-trafficmanager==0.50.0',
        'azure-mgmt-web==0.35.0',
        'azure-nspkg==3.0.2',
        'azure-servicebus==0.21.1',
        'azure-servicefabric==6.3.0.0',
        'azure-servicemanagement-legacy==0.20.7',
        'azure-storage-blob==1.5.0',
        'azure-storage-common==1.4.2',
        'azure-storage-file==1.4.0',
        'azure-storage-queue==1.4.0',
        'backports.tarfile==1.0.0',
        'blinker==1.7.0',
        'bottle==0.12.25',
        'bottle-websocket==0.2.9',
        'build==1.0.3',
        'buildozer==1.5.0',
        'CacheControl==0.13.1',
        'cachetools==5.3.2',
        'certifi==2024.2.2',
        'cffi==1.16.0',
        'chardet==3.0.4',
        'charset-normalizer==3.3.2',
        'click==8.1.7',
        'colorama==0.4.6',
        'cryptography==41.0.7',
        'Cython==0.29.19',
        'decorator==4.4.2',
        'distlib==0.3.8',
        'distro==1.9.0',
        'docutils==0.20.1',
        'Eel==0.16.0',
        'et-xmlfile==1.1.0',
        'ffpyplayer==4.5.1',
        'filelock==3.13.1',
        'firebase-admin==6.4.0',
        'Flask==3.0.2',
        'frozenlist==1.4.1',
        'fsspec==2024.3.1',
        'future==1.0.0',
        'gevent==24.2.1',
        'gevent-websocket==0.10.1',
        'google-api-core==2.15.0',
        'google-api-python-client==2.113.0',
        'google-auth==2.29.0',
        'google-auth-httplib2==0.2.0',
        'google-cloud-core==2.4.1',
        'google-cloud-firestore==2.14.0',
        'google-cloud-storage==2.14.0',
        'google-crc32c==1.5.0',
        'google-resumable-media==2.7.0',
        'googleapis-common-protos==1.62.0',
        'greenlet==3.0.3',
        'grpcio==1.60.0',
        'grpcio-status==1.60.0',
        'gTTS==2.5.1',
        'h11==0.14.0',
        'h2==3.2.0',
        'hpack==3.0.0',
        'hstspreload==2024.2.1',
        'httpcore==1.0.4',
        'httplib2==0.22.0',
        'httpx==0.27.0',
        'huggingface-hub==0.22.2',
        'hyperframe==5.2.0',
        'idna==3.6',
        'imageio==2.33.1',
        'imageio-ffmpeg==0.4.9',
        'importlib_metadata==7.1.0',
        'isodate==0.6.1',
        'itsdangerous==2.1.2',
        'jaraco.classes==3.4.0',
        'jaraco.context==5.3.0',
        'jaraco.functools==4.0.0',
        'Jinja2==3.1.3',
        'joblib==1.3.2',
        'keyring==25.1.0',
        'kivy',
        'kivy-deps.angle==0.4.0',
        'kivy-deps.glew==0.3.1',
        'kivy-deps.sdl2==0.7.0',
        'Kivy-Garden==0.1.5',
        'kivymd==1.2.0',
        'lazy_loader==0.3',
        'libretranslatepy==2.1.1',
        'librosa==0.10.1',
        'llvmlite==0.42.0',
        'lxml==5.1.0',
        'markdown-it-py==3.0.0',
        'MarkupSafe==2.1.5',
        'materialyoucolor==2.0.7',
        'mdurl==0.1.2',
        'more-itertools==10.2.0',
        'moviepy==1.0.3',
        'mpmath==1.3.0',
        'msal==1.28.0',
        'msal-extensions==1.1.0',
        'msgpack==1.0.7',
        'msrest==0.7.1',
        'msrestazure==0.6.4',
        'mtranslate==1.8',
        'multidict==6.0.5',
        'networkx==3.2.1',
        'nh3==0.2.17',
        'numba==0.59.0',
        'numpy==1.26.3',
        'oauthlib==3.2.2',
        'openai==0.6.0',
        'openpyxl==3.1.2',
        'packaging==23.2',
        'pandas==2.2.1',
        'pandas-stubs==2.2.1.240316',
        'pefile==2023.2.7',
        'pexpect==4.9.0',
        'pillow==10.3.0',
        'pip-tools==7.4.0',
        'pkginfo==1.10.0',
        'platformdirs==4.2.0',
        'pooch==1.8.1',
        'portalocker==2.8.2',
        'proglog==0.1.10',
        'proto-plus==1.23.0',
        'protobuf==4.25.2',
        'ptyprocess==0.7.0',
        'pyasn1==0.5.1',
        'pyasn1-modules==0.3.0',
        'pycparser==2.21',
        'pydantic==2.6.4',
        'pydantic_core==2.16.3',
        'pydub==0.25.1',
        'Pygments==2.17.2',
        'pyinstaller==6.5.0',
        'pyinstaller-hooks-contrib==2024.3',
        'PyJWT==2.8.0',
        'pyparsing==3.1.1',
        'pypiwin32==223',
        'pyproject_hooks==1.0.0',
        'python-dateutil==2.9.0.post0',
        'pytz==2024.1',
        'pywin32==306',
        'pywin32-ctypes==0.2.2',
        'PyYAML==6.0.1',
        'readme_renderer==43.0',
        'regex==2023.12.25',
        'requests==2.31.0',
        'requests-oauthlib==2.0.0',
        'requests-toolbelt==1.0.0',
        'rfc3986==1.5.0',
        'rich==13.7.1',
        'rsa==4.9',
        'safetensors==0.4.2',
        'scikit-learn==1.4.1.post1',
        'scipy==1.12.0',
        'sh==2.0.6',
        'six==1.16.0',
        'sniffio==1.3.0',
        'soundfile==0.12.1',
        'soxr==0.3.7',
        'supyr-struct==1.5.4',
        'sympy==1.12',
        'threadpoolctl==3.3.0',
        'tokenizers==0.15.2',
        'toml==0.10.2',
        'torchaudio==2.2.2',
        'torchvision==0.17.2',
        'tqdm==4.66.1',
        'transformers==4.39.2',
        'translate==3.6.1',
        'twine==5.0.0',
        'types-pytz==2024.1.0.20240203',
        'typing_extensions==4.9.0',
        'tzdata==2024.1',
        'uritemplate==4.1.1',
        'urllib3==2.2.1',
        'uuid==1.30',
        'virtualenv==20.25.1',
        'watch==0.2.7',
        'Werkzeug==3.0.1',
        'whichcraft==0.6.1',
        'yarl==1.9.4',
        'zipp==3.18.1',
        'zope.event==5.0',
        'zope.interface==6.2'
    ],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
